-- 蝉联奖励分配界面
Lua_FactionLeagueActAllocationWindow = class("Lua_FactionLeagueActAllocationWindow", Lua_SecondSizeWindow);
function Lua_FactionLeagueActAllocationWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_FactionLeagueActAllocationWindow";
	self.skinName = "FactionLeagueActAllocationWindow_skin";
	self.titleText = LanUtil.getValue(123929);
end
	
function Lua_FactionLeagueActAllocationWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.isDown = true;

	self.tipsTxt.text = LanUtil.getValue(123930);

	self.dragList = Lua_DragList.new(self.content, 1, Vector4(0, 0, 1080, 390));
	self.dragList:setLocation(0, -10, 0);
	self.dragList:setListCell(Lua_FactionLeagueActAllocationItem, 62, 1080, 1);

	self.rItem = Lua_RewardItem.new(self.content);
	self.rItem:setMaxShow(8);
	self.rItem:setDepth(10);
	self.rItem:setClickWin(true);
	self.rItem:setMouseEnble(true);
	self.rItem:setLocation(-492, -264, 0);

	self.sureBtn:addClickFuntion(self, self.onBtnClick);
	self.arrow:addClickFuntion(self, self.onArrowClick);

	self:addLuaEvent("rFactionLeagueActReunionInfo", self, self.updateShowList);
	self:addLuaEvent("rFactionLeagueActEndInfo", self, self.updateShowList);
end

function Lua_FactionLeagueActAllocationWindow:showWin(param)
	self:superCall("showWin", param);

	if param ~= nil and type(param) == "number" then
		self.showType = param;
		self:updateShowType();
	end
end

function Lua_FactionLeagueActAllocationWindow:onArrowClick(go)
	self.isDown = not self.isDown
	self:updateShowType();
end

function Lua_FactionLeagueActAllocationWindow:onBtnClick(go)
	local arr = DataCenter.factionLeagueActData:getAllocationList();
	if arr == nil or arr:getSize() <= 0 then
		OperateAlert.show(LanUtil.getValue(123961));
		return;
	end

	if self.showType == Lua_FactionLeagueActUtil.TYPE_REUNION then -- 蝉联奖励分配
		Lua_ProxyManager.getProxy("Lua_FactionLeagueActProxy"):sFactionLeagueActReunionAllocation(arr);
	elseif self.showType == Lua_FactionLeagueActUtil.TYPE_END then -- 终结奖励分配
		Lua_ProxyManager.getProxy("Lua_FactionLeagueActProxy"):sFactionLeagueActEndAllocation(arr);
	end
end

function Lua_FactionLeagueActAllocationWindow:updateShowType()
	local vo = DataCenter.factionLeagueActUtil:getActEndVoByNum(DataCenter.factionLeagueActData.worshipPalaceReunion);
	if vo == nil then
		self:hide();
		return;
	end

	local rewardArr;
	if self.showType == Lua_FactionLeagueActUtil.TYPE_REUNION then -- 蝉联奖励分配
		rewardArr = vo.reunionRewardsArr;
	elseif self.showType == Lua_FactionLeagueActUtil.TYPE_END then -- 终结奖励分配
		rewardArr = vo.endRewardsArr;
	else
		self:hide();
		return;
	end
	self:updateShowList();

	-- 更新奖励
	self.rItem:setRewardByToolVoList(rewardArr);
end

function Lua_FactionLeagueActAllocationWindow:updateShowList()
	local memberList = {};
	DataCenter.factionLeagueActData:resetAllocationList();
	if self.showType == Lua_FactionLeagueActUtil.TYPE_REUNION then -- 蝉联奖励分配
		memberList = DataCenter.factionLeagueActData.reunionMemberList;
	elseif self.showType == Lua_FactionLeagueActUtil.TYPE_END then -- 终结奖励分配
		memberList = DataCenter.factionLeagueActData.endMemberList;
	end

	local arr = Array();
	if memberList ~= nil then
		for i = 1, #memberList do
			arr:add(memberList[i]);
		end
	end
	arr:sort("league_pos", self.isDown);
	self.dragList:setLuaArrayData(arr, false);
end

function Lua_FactionLeagueActAllocationWindow:dispose()
	if self.dragList ~= nil then
		self.dragList:dispose();
		self.dragList = nil;
	end
	if self.rItem ~= nil then
		self.rItem:dispose();
		self.rItem = nil;
	end
	DataCenter.factionLeagueActData:resetAllocationList();

	self:superCall("dispose");
end





--------------------------------------------------





Lua_FactionLeagueActAllocationItem = class("Lua_FactionLeagueActAllocationItem", Lua_ListCell);
function Lua_FactionLeagueActAllocationItem:ctor(p)
	self:superCall("ctor", p, "FactionLeagueActAllocationItem_skin");
end

function Lua_FactionLeagueActAllocationItem:buildShowItem()
	self:superCall("buildShowItem");

	self.checkBox:setDepth(4);
	self.checkBox:addBoxChange(self, self.onBoxClick);

	self:addLuaEvent("FACTION_ACT_DATA_CHANGE", self, self.onAlloctionChange);
end

function Lua_FactionLeagueActAllocationItem:setData(data)
	self.data = data;
	if self.data ~= nil then
		self.roleName.text = data.role_name;
		self.lvlTxt.text = tostring(data.role_lvl);
		self.jobTxt.text = Lua_FactionDefine.getPositionNameByPos(data.league_pos);
		self.contribution.text = tostring(data.total_contri);
		if data.left_time == 0 then
			self.timeTxt.text = LanUtil.getValue(100747);
		else
			self.timeTxt.text = TimeTransform.getInstance():transSeconds14(data.left_time)
		end

		if data.vip == 1 then
			self.signTxt:setEnable(false);
			self.checkBox:setEnable(true);
			self.checkBox.seleted = false;
		else
			self.signTxt:setEnable(true);
			self.checkBox:setEnable(false);
		end
		self.checkBox.seleted = DataCenter.factionLeagueActData:getAllocationListState(self.data.role_index);
	else
		self.checkBox.seleted = false;
	end
end

function Lua_FactionLeagueActAllocationItem:onAlloctionChange(o)
	if self.data == nil then
		return;
	end
	self.checkBox.seleted = DataCenter.factionLeagueActData:getAllocationListState(self.data.role_index);
end

function Lua_FactionLeagueActAllocationItem:onBoxClick(state)
	if self.data == nil then
		return;
	end
	DataCenter.factionLeagueActData:setAllocationListState(self.data.role_index, state);
end